Database

Struct Database 

pub struct Database { /* private fields */ }

Implementations

Source

impl Database

pub fn new() -> Self

Creates a new database instance and loads data from the file.

Panics

Panics if the database cannot be loaded from the file system.

Source

impl Database

pub fn load(&mut self) -> Result<(), Box<dyn Error + Send + Sync>>

Loads the database from the file system.

Errors

Returns an error if the database cannot be loaded or created.

Panics

Panics if the HOME environment variable is not set.

pub fn set( &mut self, key: &str, value: &str, ) -> Result<(), Box<dyn Error + Send + Sync>>

Sets a key-value pair in the database.

Errors

Returns an error if the data cannot be written to the file.

pub fn get(&self, key: &str) -> Option<String>